<html>
	<head>
		<title>Comment Dashboard</title>
		<script src="https://ajax.googleapis.com/ajax/libs/jquery/2.1.4/jquery.min.js"></script>
		<script src="http://public.tableau.com/javascripts/api/tableau-2.0.0.min.js"></script>
		<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css" />
		<script>
			currentViz = '';
			selectedMonth = '';
			
			/**
			 * Instantiate our vizualization.
			 */
			$(function() {
				$('.detailBox').hide();
				$('.hiddenBg').hide();
				var url  = 'https://sampleServerUrl/views/SuperStoreSalesVProfit/SuperStoreSales';
				var vizOptions = {
					showTabs           : true,
					hideToolbar        : true,
					width              : "420px",
					height             : "420px"
				};
				
				currentViz = new tableauSoftware.Viz(document.getElementById('viz'), url, vizOptions);
				currentViz.addEventListener(tableauSoftware.TableauEventName.MARKS_SELECTION, onMarkSelect);
			});
			
			/**
			 * Catches the tableau event fired when a filter is changed.
			 */
			function onMarkSelect(e)
			{
				e.getMarksAsync().then(function (marks) {
					for (var i = 0; i < marks.length; i++) {
						var pairs = marks[i].getPairs();
						for (var j = 0; j < pairs.length; j++) {
							if (pairs[j].fieldName == 'MONTH(Order Date)') {
								selectedMonth = pairs[j].formattedValue;
								annotateMonth();
								return;
							}
						}
					}
				});
			}
			
			/**
			 * Annotate Month
			 */
			function annotateMonth()
			{
				$('.detailBox').fadeIn('slow');
				$('.hiddenBg').fadeIn('slow');
				$('.taskDescription').html('Add notes for <b>' + selectedMonth + '</b>:');
			}
			
			/**
			 * Saves the annotation to the database
			 */
			function saveAnnotation()
			{
				$.ajax({
					url  : "add_comment.php",
					data : {
						'month'   : selectedMonth,
						'comment' : $('#notes').val()
					}
				}).done(function() {
					var sheets = currentViz.getWorkbook().getActiveSheet().getWorksheets();
					for (var j = 0; j < sheets.length; j++) {
						sheets[j].clearSelectedMarksAsync();
					}
					currentViz.refreshDataAsync();
					$('#notes').val('');
				});
				
				hideAnnotation();
			}
			
			/**
			 * Hides the annotation from view
			 */
			function hideAnnotation()
			{
				$('.detailBox').fadeOut('slow');
				$('.hiddenBg').fadeOut('slow');
			}
		</script>
		<style>
			.hiddenBg {
				width: 100%;
				height: 100%;
				background-color: black;
				position: absolute;
				opacity: 0.75;
				top: 0px;
			}
			.detailBox {
				position: absolute;
				top: 50%;
				left: 50%;
				margin-top: -160px;
				margin-left: -160px;
				width: 320px;
				border: 1px solid #e7e7e7;
				background-color: white;
				z-index: 1;
			}
			.titleBox {
				background-color: #f8f8f8;
				border-color: #e7e7e7;
				padding: 10px;
			}
			.titleBox label{
				color: #444;
				margin: 0;
				display: inline-block;
			}
			.commentBox {
				padding: 10px;
				border-top: 1px dotted #e7e7e7;
			}
			.taskDescription {
				margin-top: 10px 0;
			}
			.actionBox {
				padding: 0px 10px;
			}
		</style>
	</head>
	<body>
		<div class="navbar navbar-default">
			<a class="navbar-brand" href="http://www.interworks.com">
				<img src="https://www.interworks.com/logo/images/logo.png" />
			</a>
		</div>
		
		<div class="hiddenBg"></div>
		<div class="detailBox">
			<div class="titleBox">
				<label>Add Notation</label>
				<button type="button" class="close" aria-hidden="true">&times;</button>
			</div>
			<div class="commentBox">
				<p class="taskDescription">Add notes for :</p>
			</div>
			<div class="actionBox">
				<form class="form" role="form">
					<div class="form-group">
						<textarea class="form-control" id="notes" placeholder="Your notes" /></textarea>
					</div>
					<div class="form-group">
						<button class="btn btn-danger" type="button" onclick="hideAnnotation();">Cancel</button>
						<button class="btn btn-success" type="button" onclick="saveAnnotation();">Save</button>
					</div>
				</form>
			</div>
		</div>
		
		<div id="viz"></div>
	</body>
</html>